"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = ZegoCallInvitationDialog;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _native = require("@react-navigation/native");
var _defines = require("../services/defines");
var _invite_state_manager = _interopRequireDefault(require("../services/invite_state_manager"));
var _logger = require("../../utils/logger");
var _bell = _interopRequireDefault(require("../services/bell"));
var _inner_text_helper = _interopRequireDefault(require("../services/inner_text_helper"));
var _call_invite_helper = _interopRequireDefault(require("../services/call_invite_helper"));
var _reactDelegateComponent = _interopRequireDefault(require("react-delegate-component"));
var _zegoUikitRn = _interopRequireWildcard(require("@zegocloud/zego-uikit-rn"));
var _services = _interopRequireDefault(require("../../services"));
var _callkit = _interopRequireDefault(require("../services/callkit"));
var _report = _interopRequireDefault(require("../../utils/report"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function ZegoCallInvitationDialog(props) {
  const TAG = 'ZegoCallInvitationDialog';
  const initConfig = _services.default.getInstance().getInitConfig();
  const {
    showDeclineButton = true,
    onIncomingCallDeclineButtonPressed,
    onIncomingCallAcceptButtonPressed,
    avatarBuilder
  } = initConfig;
  const navigation = (0, _native.useNavigation)();
  const [isInit, setIsInit] = (0, _react.useState)(false);
  const [isDialogVisable, setIsDialogVisable] = (0, _react.useState)(false);
  const [isFullScreen, setIsFullScreen] = (0, _react.useState)(false);
  const [inviteType, setInviteType] = (0, _react.useState)(_defines.ZegoInvitationType.voiceCall);
  const [inviter, setInviter] = (0, _react.useState)({});
  const [extendData, setExtendData] = (0, _react.useState)({});
  const [callID, setCallID] = (0, _react.useState)('');
  const getDialogTitle = () => {
    if (extendData.notificationTitle && extendData.notificationTitle.length > 0) {
      return extendData.notificationTitle;
    } else if (extendData.call_name && extendData.call_name.length > 0) {
      return extendData.call_name;
    } else {
      const count = extendData.invitees ? extendData.invitees.length : 0;
      return _inner_text_helper.default.instance().getIncomingCallDialogTitle(inviter.name, inviteType, count);
    }
  };
  const getDialogMessage = () => {
    if (extendData.notificationMessage && extendData.notificationMessage.length > 0) {
      return extendData.notificationMessage;
    } else {
      const count = extendData.invitees ? extendData.invitees.length : 0;
      return _inner_text_helper.default.instance().getIncomingCallDialogMessage(inviteType, count);
    }
  };
  const getShortName = name => {
    if (!name) {
      return '';
    }
    const nl = name.split(' ');
    var shotName = '';
    nl.forEach(part => {
      if (part !== '') {
        shotName += part.substring(0, 1);
      }
    });
    return shotName;
  };
  const getImageSourceByPath = () => {
    if (inviteType === _defines.ZegoInvitationType.videoCall) {
      return require('../resources/button_call_video_accept.png');
    }
  };
  const onRefuseCallback = () => {
    if (typeof onIncomingCallDeclineButtonPressed == 'function') {
      onIncomingCallDeclineButtonPressed(navigation);
    }
    setIsDialogVisable(false);
    setIsFullScreen(false);
  };
  const refuseHandle = () => {
    _call_invite_helper.default.getInstance().refuseCall(callID);
    if (_reactNative.Platform.OS === 'android') {
      _callkit.default.dismissCallNotification();
    }
  };
  const refuseSuccHandle = () => {
    (0, _logger.zloginfo)(`Refuse Call Invitation succ`);
    refuseHandle();
    _report.default.reportEvent('call/respondInvitation', {
      'call_id': callID,
      'app_state': _reactNative.AppState.currentState,
      'action': 'refuseSucc'
    });
  };
  const refuseFailHandle = error => {
    (0, _logger.zloginfo)(`Refuse Call Invitation failed, code: ${error.code}, message: ${error.message}`);
    refuseHandle();
    _report.default.reportEvent('call/respondInvitation', {
      'call_id': callID,
      'app_state': _reactNative.AppState.currentState,
      'action': 'refuseFail'
    });
  };
  const onAccectCallback = data => {
    (0, _logger.zloginfo)("onAccectCallback", data.call_id, data.inviter.id);
    if (typeof onIncomingCallAcceptButtonPressed == 'function') {
      onIncomingCallAcceptButtonPressed(navigation);
    }
    setIsDialogVisable(false);
    setIsFullScreen(false);
    navigation.navigate('ZegoUIKitPrebuiltCallInCallScreen', {
      roomID: data.call_id,
      isVideoCall: data.type === _defines.ZegoInvitationType.videoCall,
      invitees: data.invitees,
      inviter: data.inviter.id
    });
  };
  const acceptHandle = () => {
    _call_invite_helper.default.getInstance().acceptCall(callID, {
      ...extendData,
      inviteType,
      inviter
    });
    if (_reactNative.Platform.OS === 'android') {
      _callkit.default.dismissCallNotification();
    }
    _report.default.reportEvent('call/respondInvitation', {
      'call_id': callID,
      'app_state': _reactNative.AppState.currentState,
      'action': 'acceptSucc'
    });
  };
  const acceptFailHandle = error => {
    (0, _logger.zloginfo)(`Accept Call Invitation failed, code: ${error.code}, message: ${error.message}`);
    refuseHandle();
    _report.default.reportEvent('call/respondInvitation', {
      'call_id': callID,
      'app_state': _reactNative.AppState.currentState,
      'action': 'acceptFail'
    });
  };
  const pressHandle = () => {
    setIsFullScreen(true);
  };
  (0, _react.useEffect)(() => {
    const callbackID = 'ZegoCallInvitationDialog' + String(Math.floor(Math.random() * 10000));
    _services.default.getInstance().onInit(callbackID, () => {
      setIsInit(true);
    });
    _call_invite_helper.default.getInstance().onCallAccepted(callbackID, onAccectCallback);
    _call_invite_helper.default.getInstance().onCallRefused(callbackID, onRefuseCallback);
    return () => {
      _services.default.getInstance().onInit(callbackID);
      _call_invite_helper.default.getInstance().onCallAccepted(callbackID);
      _call_invite_helper.default.getInstance().onCallRefused(callbackID);
    };
  }, []);
  (0, _react.useEffect)(() => {
    if (isInit) {
      (0, _logger.zloginfo)('[ZegoCallInvitationDialog] Register callbacks after init');
      const callbackID = 'ZegoCallInvitationDialog' + String(Math.floor(Math.random() * 10000));
      _zegoUikitRn.default.getSignalingPlugin().onInvitationReceived(callbackID, async ({
        callID: invitationID,
        type,
        inviter,
        data
      }) => {
        (0, _logger.zloginfo)(`onInvitationReceived implement by ${TAG}, callID: ${invitationID}, isVideoCall: ${type}, inviter: ${inviter}, data: ${data}`);
        let onCall = _invite_state_manager.default.isOncall(invitationID);
        const onRoom = _zegoUikitRn.default.isRoomConnected();
        const offlineData = _call_invite_helper.default.getInstance().getOfflineData();
        (0, _logger.zloginfo)(`[ZegoCallInvitationDialog][onInvitationReceived] onCall: ${onCall}, onRoom: ${onRoom}, offlineData: ${offlineData}`);
        if (onCall || !offlineData && onRoom) {
          (0, _logger.zloginfo)(`Automatically declining invitations, onCall: ${onCall}, onRoom: ${onRoom}`);
          // Automatically declining invitations
          _zegoUikitRn.default.getSignalingPlugin().refuseInvitation(inviter.id, JSON.stringify({
            callID: invitationID,
            reason: 'busy'
          }));
          _invite_state_manager.default.updateInviteDataAfterRejected(invitationID);
        } else {
          const currentData = JSON.parse(data);
          if (offlineData && offlineData.call_id === currentData.call_id && offlineData.inviter.id === currentData.inviter.id) {
            _call_invite_helper.default.getInstance().acceptCall(invitationID, offlineData);
            _zegoUikitRn.default.getSignalingPlugin().acceptInvitation(inviter.id, undefined);
            _call_invite_helper.default.getInstance().setOfflineData(undefined);
          } else {
            setCallID(invitationID);
            setInviteType(type);
            setInviter(inviter);
            setExtendData(JSON.parse(data));
            setIsDialogVisable(true);
            _report.default.reportEvent('call/displayNotification', {
              'call_id': invitationID,
              'app_state': _reactNative.AppState.currentState
            });
            _bell.default.vibrate();
            if (_reactNative.AppState.currentState !== 'background') {
              _bell.default.playIncomingSound();
            }
          }
        }
      }, TAG);
      _zegoUikitRn.default.getSignalingPlugin().onInvitationTimeout(callbackID, () => {
        _bell.default.stopIncomingSound();
        _bell.default.cancleVirate();
        setIsDialogVisable(false);
        setIsFullScreen(false);
      });
      _zegoUikitRn.default.getSignalingPlugin().onInvitationCanceled(callbackID, result => {
        (0, _logger.zloginfo)(`[ZegoCallInvitationDialog] onInvitationCanceled, result: ${JSON.stringify(result)}`);
        _bell.default.stopIncomingSound();
        _bell.default.cancleVirate();
        setIsDialogVisable(false);
        setIsFullScreen(false);
      });
      return () => {
        _zegoUikitRn.default.getSignalingPlugin().onInvitationReceived(callbackID);
        _zegoUikitRn.default.getSignalingPlugin().onInvitationTimeout(callbackID);
        _zegoUikitRn.default.getSignalingPlugin().onInvitationCanceled(callbackID);
        _bell.default.stopIncomingSound();
        _bell.default.cancleVirate();
      };
    }
  }, [isInit]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.container, isDialogVisable ? styles.show : null]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Modal, {
    animationType: "fade",
    transparent: true,
    visible: isDialogVisable,
    style: styles.modal
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.mask
  }), !isFullScreen ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: pressHandle,
    activeOpacity: 0.9
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.dialog
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.left
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.avatar
  }, !avatarBuilder ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.nameLabel
  }, getShortName(inviter.name), " ") : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      width: '100%',
      height: '100%',
      alignItems: 'center',
      justifyContent: 'center'
    }
  }, /*#__PURE__*/_react.default.createElement(_reactDelegateComponent.default, {
    to: avatarBuilder,
    props: {
      userInfo: {
        userID: inviter.id,
        userName: inviter.name
      }
    }
  }))), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.callInfo
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.callName,
    numberOfLines: 1,
    ellipsizeMode: "tail"
  }, getDialogTitle()), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.callTitle
  }, getDialogMessage()))), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.right
  }, showDeclineButton ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.refuse
  }, /*#__PURE__*/_react.default.createElement(_zegoUikitRn.ZegoRefuseInvitationButton, {
    inviterID: inviter.id,
    onPressed: refuseSuccHandle,
    onFailure: refuseFailHandle,
    data: JSON.stringify({
      inviterID: inviter.id,
      reason: 'decline',
      callID
    })
  })) : null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.accept
  }, /*#__PURE__*/_react.default.createElement(_zegoUikitRn.ZegoAcceptInvitationButton, {
    icon: getImageSourceByPath(),
    inviterID: inviter.id,
    onPressed: acceptHandle,
    onFailure: acceptFailHandle
  }))))) : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.fullDialog
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.content
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.fullAvatar
  }, !avatarBuilder ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.fullNameLabel
  }, getShortName(inviter.name)) : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      width: '100%',
      height: '100%',
      alignItems: 'center',
      justifyContent: 'center'
    }
  }, /*#__PURE__*/_react.default.createElement(_reactDelegateComponent.default, {
    to: avatarBuilder,
    props: {
      userInfo: {
        userID: inviter.id,
        userName: inviter.name
      }
    }
  }))), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.fullCallName
  }, getDialogTitle()), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.calling
  }, getDialogMessage())), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.bottomBarContainer
  }, showDeclineButton ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.fullRefuse
  }, /*#__PURE__*/_react.default.createElement(_zegoUikitRn.ZegoRefuseInvitationButton, {
    inviterID: inviter.id,
    onPressed: refuseSuccHandle,
    onFailure: refuseFailHandle,
    data: JSON.stringify({
      inviterID: inviter.id,
      reason: 'decline',
      callID
    })
  }), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.fullRefuseTitle
  }, _inner_text_helper.default.instance().getInnerText().incomingCallPageDeclineButton)) : null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.fullAccept
  }, /*#__PURE__*/_react.default.createElement(_zegoUikitRn.ZegoAcceptInvitationButton, {
    icon: getImageSourceByPath(),
    inviterID: inviter.id,
    onPressed: acceptHandle,
    onFailure: acceptFailHandle
  }), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.fullAcceptTitle
  }, _inner_text_helper.default.instance().getInnerText().incomingCallPageAcceptButton))))));
}
const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1,
    position: 'absolute',
    zIndex: 10000,
    alignItems: 'center'
  },
  mask: {
    position: 'absolute',
    top: 0,
    bottom: 0,
    right: 0,
    left: 0,
    backgroundColor: '#333333',
    opacity: 0.4
  },
  dialog: {
    height: 80,
    backgroundColor: '#333333',
    borderRadius: 8,
    marginTop: 40,
    flexDirection: 'row',
    justifyContent: 'space-between',
    paddingLeft: 12,
    paddingRight: 12,
    marginLeft: 8,
    marginRight: 8
  },
  left: {
    flexDirection: 'row',
    alignItems: 'center',
    flex: 1
  },
  avatar: {
    backgroundColor: '#ffffff',
    borderRadius: 1000,
    color: '#2A2A2A',
    width: 42,
    height: 42,
    justifyContent: 'center',
    alignItems: 'center',
    marginRight: 13,
    overflow: 'hidden'
  },
  callInfo: {
    flexDirection: 'column',
    marginRight: 5,
    flex: 1
  },
  nameLabel: {
    fontSize: 26
  },
  callName: {
    fontSize: 24,
    color: '#ffffff',
    lineHeight: 25,
    marginBottom: 3.5
  },
  callTitle: {
    fontSize: 12,
    color: '#ffffff',
    opacity: 0.8,
    lineHeight: 16.5
  },
  right: {
    flexDirection: 'row',
    alignItems: 'center'
  },
  refuse: {
    marginRight: 20
  },
  fullDialog: {
    backgroundColor: '#333333',
    width: '100%',
    height: '100%'
  },
  content: {
    width: '100%',
    alignItems: 'center',
    marginTop: 114
  },
  fullAvatar: {
    width: 100,
    height: 100,
    borderRadius: 1000,
    backgroundColor: '#ffffff',
    alignItems: 'center',
    justifyContent: 'center',
    marginBottom: 5,
    overflow: 'hidden'
  },
  fullNameLabel: {
    color: '#222222',
    fontSize: 22
  },
  fullCallName: {
    fontSize: 21,
    lineHeight: 29.5,
    marginBottom: 23.5,
    color: '#ffffff'
  },
  calling: {
    fontSize: 16,
    lineHeight: 22.5,
    color: '#ffffff',
    opacity: 0.7
  },
  bottomBarContainer: {
    width: '100%',
    position: 'absolute',
    bottom: 100,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-around',
    paddingLeft: 30,
    paddingRight: 30
  },
  fullRefuse: {},
  fullRefuseTitle: {
    fontSize: 13,
    opacity: 0.7,
    color: '#FFFFFF',
    lineHeight: 18.5,
    marginTop: 7.5
  },
  fullAccept: {},
  fullAcceptTitle: {
    fontSize: 13,
    opacity: 0.7,
    color: '#FFFFFF',
    lineHeight: 18.5,
    marginTop: 7.5
  }
});
//# sourceMappingURL=ZegoCallInvitationDialog.js.map