"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = ZegoUIKitPrebuiltCallWaitingScreen;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _zegoUikitRn = _interopRequireWildcard(require("@zegocloud/zego-uikit-rn"));
var _ZegoCallInvationForeground = _interopRequireDefault(require("./ZegoCallInvationForeground"));
var _bell = _interopRequireDefault(require("../services/bell"));
var _logger = require("../../utils/logger");
var _invite_state_manager = _interopRequireDefault(require("../services/invite_state_manager"));
var _native = require("@react-navigation/native");
var _services = _interopRequireDefault(require("../../services"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function ZegoUIKitPrebuiltCallWaitingScreen(props) {
  const navigation = (0, _native.useNavigation)();
  const {
    appID,
    appSign
  } = _services.default.getInstance().getInitAppInfo();
  const {
    userID,
    userName
  } = _services.default.getInstance().getInitUser();
  const initConfig = _services.default.getInstance().getInitConfig();
  const {
    onOutgoingCallCancelButtonPressed,
    avatarBuilder,
    waitingPageConfig
  } = initConfig;
  const {
    route
  } = props;
  const {
    roomID,
    isVideoCall,
    invitees,
    inviter,
    invitationID,
    callName
  } = route.params;
  const getInviteeIDList = () => {
    return invitees.map(invitee => {
      return invitee.userID;
    });
  };
  const grantPermissions = async callback => {
    // Android: Dynamically obtaining device permissions
    if (_reactNative.Platform.OS === 'android') {
      // Check if permission granted
      let grantedAudio = _reactNative.PermissionsAndroid.check(_reactNative.PermissionsAndroid.PERMISSIONS.RECORD_AUDIO);
      let grantedCamera = _reactNative.PermissionsAndroid.check(_reactNative.PermissionsAndroid.PERMISSIONS.CAMERA);
      const ungrantedPermissions = [];
      try {
        const isAudioGranted = await grantedAudio;
        const isVideoGranted = await grantedCamera;
        if (!isAudioGranted) {
          ungrantedPermissions.push(_reactNative.PermissionsAndroid.PERMISSIONS.RECORD_AUDIO);
        }
        if (!isVideoGranted && isVideoCall) {
          ungrantedPermissions.push(_reactNative.PermissionsAndroid.PERMISSIONS.CAMERA);
        }
      } catch (error) {
        ungrantedPermissions.push(_reactNative.PermissionsAndroid.PERMISSIONS.RECORD_AUDIO, _reactNative.PermissionsAndroid.PERMISSIONS.CAMERA);
      }
      // If not, request it
      (0, _logger.zloginfo)(`[ZegoUIKitPrebuiltCallWaitingScreen] requestMultiple, ungrantedPermissions: ${ungrantedPermissions}`);
      return _reactNative.PermissionsAndroid.requestMultiple(ungrantedPermissions).then(result => {
        (0, _logger.zloginfo)(`[ZegoUIKitPrebuiltCallWaitingScreen] requestMultiple, result: ${result}`);
        if (callback) {
          callback();
        }
      });
    } else if (callback) {
      callback();
    }
  };
  const hangUpHandle = () => {
    (0, _logger.zloginfo)('[ZegoUIKitPrebuiltCallWaitingScreen] hangUpHandle, Leave room on waiting page');
    _zegoUikitRn.default.uninit();
    if (typeof onOutgoingCallCancelButtonPressed == 'function') {
      onOutgoingCallCancelButtonPressed(navigation, roomID, invitees, isVideoCall ? 1 : 0);
    }
    if (_invite_state_manager.default.isAutoCancelInvite(invitationID)) {
      _zegoUikitRn.default.getSignalingPlugin().cancelInvitation(getInviteeIDList(), JSON.stringify({
        "call_id": roomID,
        "operation_type": "cancel_invitation"
      }));
      _invite_state_manager.default.updateInviteDataAfterCancel(invitationID);
    }
    _bell.default.stopOutgoingSound();
    _invite_state_manager.default.initInviteData();
    navigation.goBack();
  };
  (0, _react.useEffect)(() => {
    _bell.default.playOutgoingSound();
    _zegoUikitRn.default.init(appID, appSign, {
      userID,
      userName
    }).then(() => {
      grantPermissions(() => {
        _zegoUikitRn.default.turnCameraOn('', isVideoCall);
        _zegoUikitRn.default.turnMicrophoneOn('', true);
        _zegoUikitRn.default.setAudioOutputToSpeaker(true);
      });
    });
    const unsubscribe1 = navigation.addListener('blur', () => {
      (0, _logger.zloginfo)('[Navigation] ZegoUIKitPrebuiltCallWaitingScreen, blur');
    });
    const unsubscribe2 = navigation.addListener('focus', () => {
      (0, _logger.zloginfo)('[Navigation] ZegoUIKitPrebuiltCallWaitingScreen, focus');
    });
    const unsubscribe3 = navigation.addListener('beforeRemove', () => {
      (0, _logger.zloginfo)('[Navigation] ZegoUIKitPrebuiltCallWaitingScreen, beforeRemove');
    });
    return () => {
      _bell.default.stopOutgoingSound();
      unsubscribe1();
      unsubscribe2();
      unsubscribe3();
    };
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const handleBackButton = () => {
    return true;
  };
  (0, _react.useEffect)(() => {
    (0, _logger.zloginfo)(`ZegoUIKitPrebuiltCallWaitingScreen useEffect, invitationID: ${invitationID}`);
    const callbackID = 'ZegoUIKitPrebuiltCallWaitingScreen' + String(Math.floor(Math.random() * 10000));
    if (invitees.length === 1) {
      _zegoUikitRn.default.getSignalingPlugin().onInvitationResponseTimeout(callbackID, () => {
        (0, _logger.zloginfo)('[ZegoUIKitPrebuiltCallWaitingScreen] onInvitationResponseTimeout');
        _zegoUikitRn.default.uninit();
        _bell.default.stopOutgoingSound();
        // ZegoUIKit.leaveRoom();
        _invite_state_manager.default.initInviteData();
        navigation.goBack();
      });
      _zegoUikitRn.default.getSignalingPlugin().onInvitationRefused(callbackID, data => {
        (0, _logger.zloginfo)('[ZegoUIKitPrebuiltCallWaitingScreen] onInvitationRefused');
        _zegoUikitRn.default.uninit();
        const callIDs = Array.from(_invite_state_manager.default._invitationMap.keys());
        if (callIDs.includes(data.callID)) {
          _bell.default.stopOutgoingSound();
          // ZegoUIKit.leaveRoom();
          _invite_state_manager.default.initInviteData();
          navigation.goBack();
        }
      });

      // After the caller initiates a call and then loses network connectivity, 
      // the server will cancel the call and notify both the caller and the callee that the call has been canceled.
      _zegoUikitRn.default.getSignalingPlugin().onInvitationCanceled(callbackID, result => {
        (0, _logger.zloginfo)(`[ZegoUIKitPrebuiltCallWaitingScreen] onInvitationCanceled, result: ${JSON.stringify(result)}`);
        if (result.callID !== invitationID) {
          (0, _logger.zlogwarning)('[ZegoUIKitPrebuiltCallWaitingScreen] onInvitationCanceled, callID not match');
          return;
        }
        _zegoUikitRn.default.uninit();
        _bell.default.stopOutgoingSound();
        _invite_state_manager.default.initInviteData();
        navigation.goBack();
      });
    } else {
      // CallInviteStateManage.onSomeoneAcceptedInvite(callbackID, () => {
      //   zloginfo('Someone accepted the invitation');
      //   BellManage.stopOutgoingSound();
      // });
      _invite_state_manager.default.onInviteCompletedWithNobody(callbackID, () => {
        (0, _logger.zloginfo)('[ZegoUIKitPrebuiltCallWaitingScreen] onInviteCompletedWithNobody');
        _zegoUikitRn.default.uninit();
        navigation.goBack();
      });
    }
    _zegoUikitRn.default.getSignalingPlugin().onInvitationAccepted(callbackID, ({
      invitee,
      data
    }) => {
      (0, _logger.zloginfo)('Jump to call room page.');
      _bell.default.stopOutgoingSound();
      // ZegoUIKit.leaveRoom().then(() => {
      navigation.navigate('ZegoUIKitPrebuiltCallInCallScreen', {
        origin: 'ZegoUIKitPrebuiltCallWaitingScreen',
        roomID,
        isVideoCall,
        invitees: getInviteeIDList(),
        inviter,
        invitationID,
        useFrontFacingCamera: _zegoUikitRn.default.isUsingFrontFacingCamera()
      });
      // });
    });
    _reactNative.BackHandler.addEventListener('hardwareBackPress', handleBackButton);
    navigation.setOptions({
      gestureEnabled: false
    });
    return () => {
      _zegoUikitRn.default.getSignalingPlugin().onInvitationResponseTimeout(callbackID);
      _zegoUikitRn.default.getSignalingPlugin().onInvitationRefused(callbackID);
      _zegoUikitRn.default.getSignalingPlugin().onInvitationCanceled(callbackID);
      _zegoUikitRn.default.getSignalingPlugin().onInvitationAccepted(callbackID);
      _invite_state_manager.default.onInviteCompletedWithNobody(callbackID);
      _reactNative.BackHandler.removeEventListener('hardwareBackPress', handleBackButton);
      navigation.setOptions({
        gestureEnabled: true
      });
    };
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.container
  }, isVideoCall ? /*#__PURE__*/_react.default.createElement(_zegoUikitRn.ZegoAudioVideoView, {
    userID: userID,
    roomID: roomID,
    useVideoViewAspectFill: true
    // eslint-disable-next-line react/no-unstable-nested-components
    ,
    foregroundBuilder: () => /*#__PURE__*/_react.default.createElement(_ZegoCallInvationForeground.default, {
      isVideoCall: isVideoCall,
      invitee: invitees[0],
      onHangUp: hangUpHandle,
      avatarBuilder: avatarBuilder,
      waitingPageConfig: waitingPageConfig,
      callName: callName,
      isGroupCall: invitees.length > 1
    })
  }) : /*#__PURE__*/_react.default.createElement(_ZegoCallInvationForeground.default, {
    isVideoCall: isVideoCall,
    invitee: invitees[0],
    onHangUp: hangUpHandle,
    avatarBuilder: avatarBuilder,
    waitingPageConfig: waitingPageConfig,
    callName: callName,
    isGroupCall: invitees.length > 1
  }), isVideoCall ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.topMenuContainer
  }, /*#__PURE__*/_react.default.createElement(_zegoUikitRn.ZegoSwitchCameraButton, {
    iconBuilder: waitingPageConfig.switchCameraBuilder
  })) : /*#__PURE__*/_react.default.createElement(_reactNative.View, null));
}
const styles = _reactNative.StyleSheet.create({
  container: {
    width: '100%',
    height: '100%',
    flex: 1
  },
  topMenuContainer: {
    zIndex: 2,
    width: '100%',
    paddingRight: 15,
    top: 30,
    alignItems: 'flex-end'
  }
});
//# sourceMappingURL=ZegoCallInvitationWaiting.js.map