"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.listeners = exports.default = void 0;
var _reactNative = require("react-native");
var _logger = require("../../utils/logger");
var _report = _interopRequireDefault(require("../../utils/report"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == typeof i ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != typeof t || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != typeof i) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
const {
  ZegoUIKitPrebuiltCallRNModule
} = _reactNative.NativeModules;
const eventEmitter = new _reactNative.NativeEventEmitter(ZegoUIKitPrebuiltCallRNModule);
const answerCall = handler => eventEmitter.addListener('RNCallKitPerformAnswerCallAction', data => {
  (0, _logger.zloginfo)('[EventListener] receive RNCallKitPerformAnswerCallAction from NativeModule');
  handler(data);
});
const endCall = handler => eventEmitter.addListener('RNCallKitPerformEndCallAction', data => {
  (0, _logger.zloginfo)('[EventListener] receive RNCallKitPerformEndCallAction from NativeModule');
  handler(data);
});
const listeners = exports.listeners = {
  answerCall,
  endCall
};
class EventListener {
  constructor(type, listener, callkit) {
    _defineProperty(this, "remove", () => {
      this._callkit.removeEventListener(this._type, this._listener);
    });
    this._type = type;
    this._listener = listener;
    this._callkit = callkit;
  }
}
class RNCallKit {
  constructor() {
    _defineProperty(this, "addEventListener", (type, handler) => {
      const listener = listeners[type](handler);
      const listenerSet = this._callkitEventHandlers.get(type) ?? new Set();
      listenerSet.add(listener);
      this._callkitEventHandlers.set(type, listenerSet);
      return new EventListener(type, listener, this);
    });
    _defineProperty(this, "removeEventListener", (type, listener = undefined) => {
      const listenerSet = this._callkitEventHandlers.get(type);
      if (!listenerSet) {
        return;
      }
      if (listener) {
        listenerSet.delete(listener);
        listener.remove();
        if (listenerSet.size <= 0) {
          this._callkitEventHandlers.delete(type);
        }
      } else {
        listenerSet.forEach(listener => {
          listener.remove();
        });
        this._callkitEventHandlers.delete(type);
      }
    });
    _defineProperty(this, "setupCallKit", options => {
      if (_reactNative.Platform.OS === 'ios') {
        return;
      }
      (0, _logger.zloginfo)('call ZegoUIKitPrebuiltCallRNModule.setupCallKit');
      ZegoUIKitPrebuiltCallRNModule.setupCallKit(options);
    });
    _defineProperty(this, "displayIncomingCall", (title, message, callID, appState) => {
      if (_reactNative.Platform.OS === 'ios') {
        return;
      }
      (0, _logger.zloginfo)('call ZegoUIKitPrebuiltCallRNModule.displayIncomingCall');
      ZegoUIKitPrebuiltCallRNModule.displayIncomingCall(title, message);
      _report.default.reportEvent('call/displayNotification', {
        'call_id': callID,
        'app_state': appState
      });
    });
    _defineProperty(this, "dismissCallNotification", () => {
      if (_reactNative.Platform.OS === 'ios') {
        return;
      }
      (0, _logger.zloginfo)('call ZegoUIKitPrebuiltCallRNModule.dismissCallNotification');
      ZegoUIKitPrebuiltCallRNModule.dismissCallNotification();
    });
    _defineProperty(this, "requestSystemAlertWindow", (message, allow, deny) => {
      if (_reactNative.Platform.OS === 'ios') {
        return;
      }
      ZegoUIKitPrebuiltCallRNModule.requestSystemAlertWindow(message, allow, deny);
    });
    _defineProperty(this, "getApiLevelSync", () => {
      if (_reactNative.Platform.OS === 'ios') {
        return 0;
      }
      return ZegoUIKitPrebuiltCallRNModule.getApiLevelSync();
    });
    this._callkitEventHandlers = new Map();
  }
}
var _default = exports.default = new RNCallKit();
//# sourceMappingURL=callkit.js.map